@@ -16,16 +16,29 @@ import copy
 import getpass
 import json
 import os
+from time import time
 
-from iconservice.base.address import is_icon_address_valid
 from iconcommons import IconConfig
+from iconcommons.logger.logger import Logger
+from iconsdk.builder.call_builder import CallBuilder
+from iconsdk.builder.transaction_builder import TransactionBuilder, CallTransactionBuilder, DeployTransactionBuilder, \
+    MessageTransactionBuilder, DepositTransactionBuilder
+from iconsdk.exception import KeyStoreException, DataTypeException
+from iconsdk.icon_service import IconService
+from iconsdk.providers.http_provider import HTTPProvider
+from iconsdk.signed_transaction import SignedTransaction
+from iconsdk.utils import add_0x_prefix
+from iconsdk.utils.convert_type import convert_hex_str_to_int, convert_bytes_to_hex_str
+from iconsdk.utils.templates import BLOCK_0_3_VERSION
+from iconsdk.wallet.wallet import KeyWallet
+from iconservice.base.address import is_icon_address_valid
 
-from tbears.config.tbears_config import FN_CLI_CONF, tbears_cli_config, keystore_test1
-from tbears.libs.icon_jsonrpc import IconClient, IconJsonrpc
-from tbears.tbears_exception import TBearsCommandException
-from tbears.util import jsonrpc_params_to_pep_style
-from tbears.util.argparse_type import IconAddress, IconPath, hash_type, non_negative_num_type
-from tbears.util.keystore_manager import validate_password, make_key_store_content
+from tbears.config.tbears_config import FN_CLI_CONF, tbears_cli_config, keystore_test1, TBEARS_CLI_TAG
+from tbears.tbears_exception import TBearsCommandException, JsonContentsException
+from tbears.util.arg_parser import uri_parser
+from tbears.util.argparse_type import IconAddress, IconPath, hash_type, non_negative_num_type, loop
+from tbears.util.keystore_manager import validate_password
+from tbears.util.transaction_logger import call_with_logger, send_transaction_with_logger
 
 
 class CommandWallet:
@@ -33,6 +46,7 @@ class CommandWallet:
         self._add_txresult_parser(subparsers)
         self._add_transfer_parser(subparsers)
         self._add_keystore_parser(subparsers)
+        self._add_keyinfo_parser(subparsers)
         self._add_balance_parser(subparsers)
         self._add_totalsupply_parser(subparsers)
         self._add_scoreapi_parser(subparsers)
@@ -42,6 +56,20 @@ class CommandWallet:
         self._add_blockbyheight_parser(subparsers)
         self._add_sendtx_parser(subparsers)
         self._add_call_parser(subparsers)
+        self._add_block_parser(subparsers)
+
+    @staticmethod
+    def _add_block_parser(subparsers):
+        parser = subparsers.add_parser('block',
+                                       help="Get block info using given argument."
+                                            "Only one of `number` and `hash` arguments can be passed.")
+        parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
+        parser.add_argument('-i', '--id', dest='hash', type=hash_type, help='Hash of the block to be queried.')
+        parser.add_argument('-n', '--number', dest='number', type=non_negative_num_type,
+                            help='Height of the block to be queried.')
+        parser.add_argument('-c', '--config', type=IconPath(),
+                            help=f'Configuration file path. This file defines the default value for '
+                                 f'"uri" (default: {FN_CLI_CONF}). This command returns the block as it was stored.')
 
     @staticmethod
     def _add_lastblock_parser(subparsers):
@@ -49,7 +77,7 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF}). This command returns the block in v0.1a format')
 
     @staticmethod
     def _add_blockbyhash_parser(subparsers):
@@ -59,7 +87,7 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF}). This command returns the block in v0.1a format')
 
     @staticmethod
     def _add_blockbyheight_parser(subparsers):
@@ -69,7 +97,8 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF}). This command returns the block in v0.1a format')
+
     @staticmethod
     def _add_txresult_parser(subparsers):
         parser = subparsers.add_parser('txresult', help='Get transaction result by transaction hash',
@@ -78,14 +107,14 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_transfer_parser(subparsers):
         parser = subparsers.add_parser('transfer', help='Transfer ICX coin.', description='Transfer ICX coin.')
         parser.add_argument('-f', '--from', type=IconAddress(), help='From address.')
         parser.add_argument('to', type=IconAddress(), help='Recipient')
-        parser.add_argument("value", type=float, help='Amount of ICX coin in loop to transfer (1 icx = 1e18 loop)')
+        parser.add_argument("value", type=loop, help='Amount of ICX coin in loop to transfer (1 icx = 1e18 loop)')
         parser.add_argument('-k', '--key-store', type=IconPath(), dest='keyStore',
                             help='Keystore file path. Used to generate "from" address and transaction signature')
         parser.add_argument('-n', '--nid', help='Network ID (default: 0x3)')
@@ -93,18 +122,31 @@ class CommandWallet:
         parser.add_argument('-p', '--password', help='Keystore file\'s password', dest='password')
         parser.add_argument('-s', '--step-limit', dest='stepLimit', type=non_negative_num_type, help='Step limit')
         parser.add_argument('-c', '--config', type=IconPath(),
-                            help=f'Configuration file path. This file defines the default values for the properties '
+                            help=f'Configuration file path. This file defines the default values for '
                                  f'"keyStore", "uri", "from" and "stepLimit". (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_keystore_parser(subparsers):
         parser = subparsers.add_parser('keystore',
-                                       help='Create keystore file in passed path.',
-                                       description='Create keystore file in passed path. Generate privatekey, '
+                                       help='Create a keystore file in the specified path',
+                                       description='Create keystore file in the specified path. Generate privatekey, '
                                                    'publickey pair using secp256k1 library.')
         parser.add_argument('path', type=IconPath('w'), help='Path of keystore file.')
         parser.add_argument('-p', '--password', help='Keystore file\'s password', dest='password')
 
+    @staticmethod
+    def _add_keyinfo_parser(subparsers):
+        parser = subparsers.add_parser('keyinfo',
+                                       help='Show a keystore information in the specified path',
+                                       description="Show a keystore information(address, privateKey, publicKey) "                                                
+                                                   "in the specified path. If you want to get privateKey, "
+                                                   "input --private-key option"
+                                       )
+        parser.add_argument('path', type=IconPath(), help='Path of keystore file.')
+        parser.add_argument('-p', '--password', help='Keystore file\'s password', dest='password')
+        parser.add_argument('--private-key', help='option that whether show privateKey', action='store_true',
+                            dest='privateKey')
+
     @staticmethod
     def _add_balance_parser(subparsers):
         parser = subparsers.add_parser('balance',
@@ -114,7 +156,7 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_totalsupply_parser(subparsers):
@@ -123,17 +165,17 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_scoreapi_parser(subparsers):
-        parser = subparsers.add_parser('scoreapi', help='Get score\'s api using given score address',
-                                       description='Get score\'s api using given score address')
-        parser.add_argument('address', type=IconAddress('cx'), help='Score address to query score api')
+        parser = subparsers.add_parser('scoreapi', help='Get SCORE\'s API using given SCORE address',
+                                       description='Get SCORE\'s API using given SCORE address')
+        parser.add_argument('address', type=IconAddress('cx'), help='SCORE address to query the API')
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath,
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_txbyhash_parser(subparsers):
@@ -143,35 +185,35 @@ class CommandWallet:
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_sendtx_parser(subparsers):
-        parser = subparsers.add_parser('sendtx', help='Request icx_sendTransaction with user input json file and '
-                                                      'keystore file. If keystore file is not given, tbears sends'
-                                                      ' request as it is in the json file.',
-                                       description='Request icx_sendTransaction with user input json file and keystore'
-                                                   ' file. If keystore file is not given, tbears sends request as it is'
-                                                   ' in the json file.')
+        parser = subparsers.add_parser('sendtx', help='Request icx_sendTransaction with the specified json file and '
+                                                      'keystore file. If keystore file is not given, tbears sends a '
+                                                      'request as it is in the json file.',
+                                       description='Request icx_sendTransaction with the specified json file and '
+                                                   'keystore file. If keystore file is not given, tbears sends a '
+                                                   'request as it is in the json file.')
         parser.add_argument('json_file', type=IconPath(), help='File path containing icx_sendTransaction content')
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
-        parser.add_argument('-k', '--key-store', type=IconPath(), help='Keystore file path. Used to generate "from"'
-                                                                       'address and transaction signature',
-                            dest='keyStore')
-        parser.add_argument('-c', '--config', type=IconPath(),
-                            help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+        parser.add_argument('-k', '--key-store', dest='keyStore', type=IconPath(),
+                            help='Keystore file path. Used to generate "from" address and transaction signature')
         parser.add_argument('-p', '--password', help='Keystore file\'s password', dest='password')
+        parser.add_argument('-s', '--step-limit', dest='stepLimit', type=non_negative_num_type, help='Step limit')
+        parser.add_argument('-c', '--config', type=IconPath(),
+                            help=f'Configuration file path. This file defines the default values for '
+                            f'"keyStore", "uri", "from" and "stepLimit". (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _add_call_parser(subparsers):
-        parser = subparsers.add_parser('call', help='Request icx_call with user input json file.',
-                                       description='Request icx_call with user input json file.')
+        parser = subparsers.add_parser('call', help='Request icx_call with the specified json file.',
+                                       description='Request icx_call with the specified json file.')
         parser.add_argument('json_file', type=IconPath(), help='File path containing icx_call content')
         parser.add_argument('-u', '--node-uri', dest='uri', help='URI of node (default: http://127.0.0.1:9000/api/v3)')
         parser.add_argument('-c', '--config', type=IconPath(),
                             help=f'Configuration file path. This file defines the default value for '
-                                 f'the "uri" (default: {FN_CLI_CONF})')
+                                 f'"uri" (default: {FN_CLI_CONF})')
 
     @staticmethod
     def _check_transfer(conf: dict, password: str = None):
@@ -184,10 +226,6 @@ class CommandWallet:
             if index == -1 or uri[index + len('127.0.0.1')] != ':':
                 raise TBearsCommandException(f'Do not transfer to "test1" account')
 
-        # value must be a integer value
-        if conf['value'] != float(int(conf['value'])):
-            raise TBearsCommandException(f'You entered invalid value {conf["value"]}')
-
         if conf.get('keyStore', None):
             if not password:
                 password = getpass.getpass("Input your keystore password: ")
@@ -208,6 +246,13 @@ class CommandWallet:
                                          "and special character.")
         return password
 
+    @staticmethod
+    def _check_keyinfo(password: str):
+        if not password:
+            password = getpass.getpass("Input your keystore password: ")
+
+        return password
+
     @staticmethod
     def _check_sendtx(conf: dict, password: str = None):
         if conf.get('keyStore', None):
@@ -221,20 +266,46 @@ class CommandWallet:
 
         return password
 
+    def block(self, conf):
+        """Query block with given parameter(height or hash)
+
+        :param conf: block command configuration
+        :return: result of query
+        """
+        uri, version = uri_parser(conf['uri'])
+        icon_service, response = IconService(HTTPProvider(uri, version)), None
+        hash, number = conf.get('hash'), conf.get('number')
+        if hash is not None and number is not None:
+            raise TBearsCommandException("Only one of id and number can be passed.")
+        if hash is not None:
+            response = icon_service.get_block(hash, True, BLOCK_0_3_VERSION)
+        if number is not None:
+            response = icon_service.get_block(convert_hex_str_to_int(number), True, BLOCK_0_3_VERSION)
+        if response is None:
+            raise TBearsCommandException("You have to specify block height or block hash")
+
+        if "error" in response:
+            print(json.dumps(response, indent=4))
+        else:
+            print(f"block info : {json.dumps(response, indent=4)}")
+
+        return response
+
     def lastblock(self, conf):
         """Query last block
 
         :param conf: lastblock command configuration
         :return: result of query
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getLastBlock())
+        response = icon_service.get_block("latest", True)
 
         if "error" in response:
             print(json.dumps(response, indent=4))
         else:
-            print(f'block info : {json.dumps(response, indent=4)}')
+            print(f"block info : {json.dumps(response, indent=4)}")
 
         return response
 
@@ -244,9 +315,10 @@ class CommandWallet:
         :param conf: blockbyheight command configuration
         :return: result of query
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getBlockByHeight(conf['height']))
+        response = icon_service.get_block(convert_hex_str_to_int(conf['height']), True)
 
         if "error" in response:
             print('Got an error response')
@@ -262,9 +334,10 @@ class CommandWallet:
         :param conf: blockbyhash command configuration
         :return: result of query
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getBlockByHash(conf['hash']))
+        response = icon_service.get_block(conf['hash'], True)
 
         if "error" in response:
             print('Got an error response')
@@ -280,15 +353,16 @@ class CommandWallet:
         :param conf: txbyhash command configuration.
         :return: result of query.
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getTransactionByHash(conf['hash']))
+        response = icon_service.get_transaction(conf['hash'], True)
 
         if "error" in response:
             print('Got an error response')
             print(f"Can not get transaction \n{json.dumps(response, indent=4)}")
         else:
-            print(f"Transaction: {json.dumps(response, indent=4)}")
+            print(f"Transaction : {json.dumps(response, indent=4)}")
 
         return response
 
@@ -298,19 +372,20 @@ class CommandWallet:
         :param conf: txresult command configuration.
         :return: result of query.
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getTransactionResult(conf['hash']))
+        response = icon_service.get_transaction_result(conf['hash'], True)
 
         if "error" in response:
             print('Got an error response')
-            print(f"Can not get transaction result \n{json.dumps(response, indent=4)}")
+            print(f"Can not get transaction \n{json.dumps(response, indent=4)}")
         else:
-            print(f"Transaction result: {json.dumps(response, indent=4)}")
+            print(f"Transaction : {json.dumps(response, indent=4)}")
 
         return response
 
-    def transfer(self, conf: dict):
+    def transfer(self, conf: dict) -> dict:
         """Transfer ICX Coin.
 
         :param conf: transfer command configuration.
@@ -322,19 +397,44 @@ class CommandWallet:
         password = self._check_transfer(conf, password)
 
         if password:
-            transfer = IconJsonrpc.from_key_store(conf['keyStore'], password)
+            try:
+                wallet = KeyWallet.load(conf['keyStore'], password)
+                from_ = wallet.get_address()
+
+            except KeyStoreException as e:
+                print(e.args[0])
+                return None
         else:
-            transfer = IconJsonrpc.from_string(conf['from'])
+            # make dummy wallet
+            wallet = KeyWallet.create()
+            from_ = conf['from']
 
-        # make JSON-RPC 2.0 request standard format (dict type)
-        request = transfer.sendTransaction(to=conf['to'],
-                                           value=hex(int(conf['value'])),
-                                           nid=conf['nid'],
-                                           step_limit=conf['stepLimit'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        # request to rpcserver
-        icon_client = IconClient(conf['uri'])
-        response = icon_client.send(request=request)
+        transaction = TransactionBuilder() \
+            .from_(from_) \
+            .to(conf['to']) \
+            .value(int(conf['value'])) \
+            .nid(convert_hex_str_to_int(conf['nid'])) \
+            .timestamp(int(time() * 10 ** 6)) \
+            .build()
+
+        if 'stepLimit' not in conf:
+            step_limit = icon_service.estimate_step(transaction)
+        else:
+            step_limit = convert_hex_str_to_int(conf['stepLimit'])
+
+        transaction.step_limit = step_limit
+
+        # Returns the signed transaction object having a signature
+        signed_transaction = SignedTransaction(transaction, wallet)
+
+        if not password:
+            signed_transaction.signed_transaction_dict['signature'] = 'sig'
+
+        # Sends transaction and return response
+        response = send_transaction_with_logger(icon_service, signed_transaction, uri)
 
         if 'result' in response:
             print('Send transfer request successfully.')
@@ -347,7 +447,7 @@ class CommandWallet:
         return response
 
     def keystore(self, conf: dict):
-        """Make keystore file with passed path and password.
+        """Create a keystore file with the specified path and password.
 
         :param conf: keystore command configuration
         """
@@ -355,21 +455,46 @@ class CommandWallet:
         password = conf.get('password', None)
         password = self._check_keystore(password)
 
-        key_store_content = make_key_store_content(password)
-
-        with open(conf['path'], mode='wb') as ks:
-            ks.write(json.dumps(key_store_content).encode())
+        key_store_content = KeyWallet.create()
+        key_store_content.store(conf['path'], password)
 
         print(f"Made keystore file successfully")
 
+    def keyinfo(self, conf: dict):
+        """Show a keystore information with the the specified path and password.
+
+        :param conf: keyinfo command configuration
+        """
+        password = conf.get('password', None)
+        password = self._check_keyinfo(password)
+
+        try:
+            wallet = KeyWallet.load(conf['path'], password)
+
+            key_info = {
+                "address": wallet.get_address(),
+                "publicKey": convert_bytes_to_hex_str(wallet.public_key)
+            }
+
+            if conf['privateKey']:
+                key_info['privateKey'] = add_0x_prefix(wallet.get_private_key())
+
+            print(json.dumps(key_info, indent=4))
+
+            return key_info
+
+        except KeyStoreException as e:
+            print(e.args[0])
+
     def balance(self, conf: dict):
         """Query icx balance of given address
 
         :param conf: balance command configuration.
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getBalance(conf['address']))
+        response = icon_service.get_balance(conf['address'], True)
 
         if "error" in response:
             print('Got an error response')
@@ -377,6 +502,7 @@ class CommandWallet:
         else:
             print(f"balance in hex: {response['result']}")
             print(f"balance in decimal: {int(response['result'], 16)}")
+
         return response
 
     @staticmethod
@@ -385,9 +511,10 @@ class CommandWallet:
 
         :param conf: totalsupply command configuration
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
 
-        response = icon_client.send(IconJsonrpc.getTotalSupply())
+        response = icon_service.get_total_supply(True)
 
         if "error" in response:
             print('Got an error response')
@@ -404,8 +531,10 @@ class CommandWallet:
         :param conf: scoreapi command configuration.
         :return: result of query.
         """
-        icon_client = IconClient(conf['uri'])
-        response = icon_client.send(IconJsonrpc.getScoreApi(conf['address']))
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
+
+        response = icon_service.get_score_api(conf['address'], True)
 
         if "error" in response:
             print('Got an error response')
@@ -426,16 +555,38 @@ class CommandWallet:
 
         password = conf.get('password', None)
         password = self._check_sendtx(conf, password)
+        params = payload['params']
 
-        if password:
-            sendtx = IconJsonrpc.from_key_store(conf['keyStore'], password)
-            params = payload['params']
-            params['from'] = None
-            jsonrpc_params_to_pep_style(params)
-            payload = sendtx.sendTransaction(**params)
+        if password and conf.get('keyStore'):
+            try:
+                wallet = KeyWallet.load(conf['keyStore'], password)
+                params['from'] = wallet.get_address()
 
-        icon_client = IconClient(conf['uri'])
-        response = icon_client.send(request=payload)
+            except KeyStoreException as e:
+                print(e.args[0])
+                return None
+        else:
+            # make dummy wallet
+            wallet = KeyWallet.create()
+
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
+
+        transaction = self.get_transaction(conf, params)
+        if 'stepLimit' not in conf:
+            step_limit = icon_service.estimate_step(transaction)
+        else:
+            step_limit = convert_hex_str_to_int(conf['stepLimit'])
+
+        transaction.step_limit = step_limit
+
+        signed_transaction = SignedTransaction(transaction, wallet)
+
+        if not password:
+            signed_transaction.signed_transaction_dict['signature'] = 'sig'
+
+        # Sends transaction
+        response = send_transaction_with_logger(icon_service, signed_transaction, uri)
 
         if 'result' in response:
             print('Send transaction request successfully.')
@@ -454,11 +605,20 @@ class CommandWallet:
         :param conf: call command configuration.
         :return: response of icx_call
         """
-        icon_client = IconClient(conf['uri'])
+        uri, version = uri_parser(conf['uri'])
+        icon_service = IconService(HTTPProvider(uri, version))
+
         with open(conf['json_file'], 'r') as jf:
             payload = json.load(jf)
 
-        response = icon_client.send(request=payload)
+        call = CallBuilder()\
+            .from_(conf['from'])\
+            .to(payload['params']['to'])\
+            .method(payload['params']['data']['method'])\
+            .params(payload['params']['data'].get('params', None))\
+            .build()
+
+        response = call_with_logger(icon_service, call, uri)
 
         if 'error' in response:
             print(json.dumps(response, indent=4))
@@ -475,7 +635,9 @@ class CommandWallet:
             raise TBearsCommandException(f"Invalid command {args.command}")
 
         user_input = vars(args)
-        conf = self.get_icon_conf(args.command, args= user_input)
+        conf = self.get_icon_conf(args.command, args=user_input)
+
+        Logger.info(f"Run '{args.command}' command with config: {conf}", TBEARS_CLI_TAG)
 
         # run command
         return getattr(self, args.command)(conf)
@@ -505,3 +667,46 @@ class CommandWallet:
             conf.update_conf(args)
 
         return conf
+
+    @staticmethod
+    def get_transaction(conf: dict, params: dict):
+        data_type = params.get('dataType')
+        params_data = params.get('data', {})
+
+        try:
+            transaction_params = {
+                "from_": params['from'],
+                "to": params['to'],
+                "nid": convert_hex_str_to_int(conf['nid']),
+                "value": convert_hex_str_to_int(params.get('value', "0x0"))
+            }
+
+            if data_type is None:
+                transaction_builder = TransactionBuilder(**transaction_params)
+            elif data_type == "call":
+                transaction_params['method'] = params_data.get('method')
+                transaction_params['params'] = params_data.get('params')
+                transaction_builder = CallTransactionBuilder(**transaction_params)
+            elif data_type == "deploy":
+                transaction_params['content'] = params_data.get('content')
+                transaction_params['content_type'] = params_data.get('contentType')
+                transaction_params['params'] = params_data.get('params')
+                transaction_builder = DeployTransactionBuilder(**params)
+            elif data_type == "message":
+                transaction_params['data'] = params_data
+                transaction_builder = MessageTransactionBuilder(**transaction_params)
+            elif data_type == "deposit":
+                transaction_params['action'] = params_data.get('action')
+                transaction_params['id'] = params_data.get('id')
+                transaction_builder = DepositTransactionBuilder(**transaction_params)
+            else:
+                raise JsonContentsException("Invalid dataType")
+            transaction = transaction_builder.build()
+        except KeyError:
+            raise JsonContentsException("Invalid json content. check json contents")
+        except TypeError:
+            raise JsonContentsException("Invalid json content. check keys")
+        except DataTypeException:
+            raise JsonContentsException("Invalid json content. check values")
+        else:
+            return transaction
